@@ -935,7 +935,7 @@ gog_view_get_toolkit (GogView *view)
  * @view : #GogView
  * @x : in coords
  * @y : in coords
- * @gobj : non-%NULL storage.
+ * @gobj : pointed object or NULL
  *
  * Returns: tool under cursor for a given view, or %NULL
  **/
@@ -966,8 +966,8 @@ gog_view_get_tool_at_point (GogView *view, double x, double y, GogObject **gobj)
  * @view : #GogView
  * @x : cursor x position
  * @y : cursor y position
- * @obj : pointed object
- * @tool : pointed tool
+ * @obj : pointed object or NULL
+ * @tool : pointed tool or NULL
  *
  * Gets view under cursor, searching recursively from @view. Corresponding object
  * is stored in @obj. This object may or may not be @view->model of pointed view.
@@ -981,6 +981,7 @@ gog_view_get_view_at_point (GogView *view, double x, double y, GogObject **obj,
 	GogView *pointed_view;
 	GSList const *ptr;
 	GSList *list;
+	GogTool *current_tool;
 
 	g_return_val_if_fail (GOG_IS_VIEW (view), NULL);
 
@@ -995,10 +996,31 @@ gog_view_get_view_at_point (GogView *view, double x, double y, GogObject **obj,
 	}
 	g_slist_free (list);
 
-	*tool = gog_view_get_tool_at_point (view, x, y, obj);
-	if (*tool != NULL)
+	if ((current_tool = gog_view_get_tool_at_point (view, x, y, obj))) {
+		if (tool != NULL)
+			*tool = current_tool;
 		return view;
+	}
 
-	*obj = NULL;
+	if (obj && *obj)
+		*obj = NULL;
 	return NULL;
 }
+
+/**
+ * gog_view_get_tip_at_point:
+ * @view : #GogView
+ * @x : x position
+ * @y : y position
+ *
+ * Gets a tip string related to the position as defined by (@x,@y) in @view.
+ *
+ * return value: the newly allocated tip string if the view class supports
+ * that or NULL.
+ **/
+char*
+gog_view_get_tip_at_point (GogView *view, double x, double y)
+{
+	GogViewClass *klass = GOG_VIEW_GET_CLASS (view);
+	return (klass->get_tip_at_point != NULL)? (klass->get_tip_at_point) (view, x, y): NULL;
+}
